@@ -235,6 +235,14 @@ def mxdt2py_dt(mxDateTime):
 		)
 		raise
 #===========================================================================
+def format_dob(dob, format='%x', encoding=None, none_string=None):
+	if dob is None:
+		if none_string is None:
+			return _('** DOB unknown **')
+		return none_string
+
+	return pydt_strftime(dob, format = format, encoding = encoding, accuracy = acc_days)
+#---------------------------------------------------------------------------
 def pydt_strftime(dt, format='%c', encoding=None, accuracy=None):
 
 	if encoding is None:
