@@ -42,6 +42,7 @@ from Gnumed.pycommon import gmDispatcher, gmTools
 # ========================================================================
 known_hooks = [
 	u'post_patient_activation',
+	u'post_person_creation',
 
 	u'shutdown-post-GUI',
 	u'startup-after-GUI-init',
@@ -116,13 +117,19 @@ def run_script(hook=None):
 		)
 		return False
 
-	script_mode = stat.S_IMODE(os.stat(full_script).st_mode)
-	if script_mode != 384:				# octal 0600
-		gmDispatcher.send (
-			signal = 'statustext',
-			msg = _('Script must be readable by the calling user only (permissions "0600"): [%s].') % full_script
-		)
-		return False
+	script_stat_val = os.stat(full_script)
+	_log.debug('hook script stat(): %s', script_stat_val)
+	script_perms = stat.S_IMODE(script_stat_val.st_mode)
+	_log.debug('hook script mode: %s (oktal: %s)', script_perms, oct(script_perms))
+	if script_perms != 384:				# octal 0600
+		if os.name in ['nt']:
+			_log.warning('this platform does not support os.stat() file permission checking')
+		else:
+			gmDispatcher.send (
+				signal = 'statustext',
+				msg = _('Script must be readable by the calling user only (permissions "0600"): [%s].') % full_script
+			)
+			return False
 
 	try:
 		tmp = gmTools.import_module_from_directory(script_path, script_name)
